==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/twofactor_totp/l10n/en_GB.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "You enabled TOTP two-factor authentication for your account",
    "You disabled TOTP two-factor authentication for your account" : "You disabled TOTP two-factor authentication for your account",
    "TOTP two-factor authentication disabled by the administration" : "TOTP two-factor authentication disabled by the administration",
    "TOTP (Authenticator app)" : "TOTP (Authenticator app)",
    "Authenticate with a TOTP app" : "Authenticate with a TOTP app",
    "Two-Factor TOTP Provider" : "Two-Factor TOTP Provider",
    "Two-factor TOTP provider" : "Two-factor TOTP provider",
    "A two-factor authentication provider for TOTP (RFC 6238)" : "A two-factor authentication provider for TOTP (RFC 6238)",
    "Could not enable TOTP" : "Could not enable TOTP",
    "Could not verify your key. Please try again" : "Could not verify your key. Please try again",
    "Enable TOTP" : "Enable TOTP",
    "Your new TOTP secret is:" : "Your new TOTP secret is:",
    "For quick setup, scan this QR code with your TOTP app:" : "For quick setup, scan this QR code with your TOTP app:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "After you configured your app, enter a test code below to ensure everything works correctly:",
    "Authentication code" : "Authentication code",
    "Verify" : "Verify",
    "Get the authentication code from the two-factor authentication app on your device." : "Get the authentication code from the two-factor authentication app on your device.",
    "Submit" : "Submit",
    "TOTP two-factor authentication disabled by an admin" : "TOTP two-factor authentication disabled by an admin",
    "TOTP two-factor provider" : "TOTP two-factor provider",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "A Two-Factor-Auth Provider for TOTP (RFC 6238)"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/twofactor_totp/l10n/en_GB.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "You enabled TOTP two-factor authentication for your account",
    "You disabled TOTP two-factor authentication for your account" : "You disabled TOTP two-factor authentication for your account",
    "TOTP two-factor authentication disabled by the administration" : "TOTP two-factor authentication disabled by the administration",
    "TOTP (Authenticator app)" : "TOTP (Authenticator app)",
    "Authenticate with a TOTP app" : "Authenticate with a TOTP app",
    "Two-Factor TOTP Provider" : "Two-Factor TOTP Provider",
    "Two-factor TOTP provider" : "Two-factor TOTP provider",
    "A two-factor authentication provider for TOTP (RFC 6238)" : "A two-factor authentication provider for TOTP (RFC 6238)",
    "Could not enable TOTP" : "Could not enable TOTP",
    "Could not verify your key. Please try again" : "Could not verify your key. Please try again",
    "Could not confirm TOTP" : "Could not confirm TOTP",
    "Enable TOTP" : "Enable TOTP",
    "Your new TOTP secret is:" : "Your new TOTP secret is:",
    "For quick setup, scan this QR code with your TOTP app:" : "For quick setup, scan this QR code with your TOTP app:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "After you configured your app, enter a test code below to ensure everything works correctly:",
    "Authentication code" : "Authentication code",
    "Verify" : "Verify",
    "Get the authentication code from the two-factor authentication app on your device." : "Get the authentication code from the two-factor authentication app on your device.",
    "Submit" : "Submit"
},
"nplurals=2; plural=(n != 1);");
